@@ -5,8 +5,8 @@ from ..diagonal import Diagonal
 __all__ = []
 
 
-@B.dispatch(B.Numeric, B.Int)
-def fill_diag(a, diag_len):
+@B.dispatch
+def fill_diag(a: B.Numeric, diag_len: B.Int):
     """Fill the diagonal of a diagonal matrix with a particular scalar.
 
     Args:
@@ -16,4 +16,4 @@ def fill_diag(a, diag_len):
     return Diagonal(a * B.ones(B.dtype(a), diag_len))
 
 
-B.fill_diag = fill_diag
+B.fill_diag = fill_diag
\ No newline at end of file
