@@ -15,23 +15,23 @@ from ..woodbury import Woodbury
 __all__ = []
 
 
-def _reverse_call(*types):
-    @B.multiply.extend(*reversed(types))
-    def multiply(a, b):
+def _reverse_call(t0, t1):
+    @B.multiply.dispatch
+    def multiply(a: t1, b: t0):
         return multiply(b, a)
 
 
 # Zero
 
 
-@B.dispatch(AbstractMatrix, Zero, precedence=proven())
-def multiply(a, b):
+@B.dispatch(precedence=proven())
+def multiply(a: AbstractMatrix, b: Zero):
     assert_compatible(a, b)
     return b
 
 
-@B.dispatch(Zero, AbstractMatrix, precedence=proven())
-def multiply(a, b):
+@B.dispatch(precedence=proven())
+def multiply(a: Zero, b: AbstractMatrix):
     assert_compatible(a, b)
     return a
 
@@ -39,8 +39,8 @@ def multiply(a, b):
 # Dense
 
 
-@B.dispatch(AbstractMatrix, AbstractMatrix)
-def multiply(a, b):
+@B.dispatch
+def multiply(a: AbstractMatrix, b: AbstractMatrix):
     if structured(a, b):
         warn_upmodule(
             f"Multiplying {a} and {b}: converting to dense.", category=ToDenseWarning
@@ -48,21 +48,21 @@ def multiply(a, b):
     return Dense(B.multiply(B.dense(a), B.dense(b)))
 
 
-@B.dispatch(Dense, Dense)
-def multiply(a, b):
+@B.dispatch
+def multiply(a: Dense, b: Dense):
     return Dense(B.multiply(a.mat, b.mat))
 
 
 # Diagonal
 
 
-@B.dispatch(Diagonal, Diagonal)
-def multiply(a, b):
+@B.dispatch
+def multiply(a: Diagonal, b: Diagonal):
     return Diagonal(B.multiply(a.diag, b.diag))
 
 
-@B.dispatch(Diagonal, AbstractMatrix)
-def multiply(a, b):
+@B.dispatch
+def multiply(a: Diagonal, b: AbstractMatrix):
     assert_compatible(a, b)
     # In the case of broadcasting, `B.diag(b)` will not get the diagonal of the
     # broadcasted version of `b`, so we exercise extra caution in that case.
@@ -80,14 +80,14 @@ _reverse_call(Diagonal, AbstractMatrix)
 # Constant
 
 
-@B.dispatch(Constant, Constant)
-def multiply(a, b):
+@B.dispatch
+def multiply(a: Constant, b: Constant):
     assert_compatible(a, b)
     return Constant(a.const * b.const, *broadcast(a, b).as_tuple())
 
 
-@B.dispatch(Constant, AbstractMatrix)
-def multiply(a, b):
+@B.dispatch
+def multiply(a: Constant, b: AbstractMatrix):
     assert_compatible(a, b)
     if structured(b):
         warn_upmodule(
@@ -96,8 +96,8 @@ def multiply(a, b):
     return Dense(a.const * B.dense(b))
 
 
-@B.dispatch(Constant, Diagonal)
-def multiply(a, b):
+@B.dispatch
+def multiply(a: Constant, b: Diagonal):
     assert_compatible(a, b)
     return Diagonal(a.const * b.diag)
 
@@ -109,19 +109,19 @@ _reverse_call(Constant, Diagonal)
 # LowerTriangular
 
 
-@B.dispatch(LowerTriangular, LowerTriangular)
-def multiply(a, b):
+@B.dispatch
+def multiply(a: LowerTriangular, b: LowerTriangular):
     return LowerTriangular(B.multiply(a.mat, b.mat))
 
 
-@B.dispatch(LowerTriangular, AbstractMatrix)
-def multiply(a, b):
+@B.dispatch
+def multiply(a: LowerTriangular, b: AbstractMatrix):
     # TODO: Optimise away `B.dense` call.
     return LowerTriangular(a.mat * B.dense(b))
 
 
-@B.dispatch(LowerTriangular, Constant)
-def multiply(a, b):
+@B.dispatch
+def multiply(a: LowerTriangular, b: Constant):
     return LowerTriangular(B.multiply(a.mat, b.const))
 
 
@@ -134,24 +134,24 @@ redirect(B.multiply, (LowerTriangular, Diagonal), (AbstractMatrix, Diagonal))
 # UpperTriangular
 
 
-@B.dispatch(UpperTriangular, UpperTriangular)
-def multiply(a, b):
+@B.dispatch
+def multiply(a: UpperTriangular, b: UpperTriangular):
     return UpperTriangular(B.multiply(a.mat, b.mat))
 
 
-@B.dispatch(UpperTriangular, LowerTriangular)
-def multiply(a, b):
+@B.dispatch
+def multiply(a: UpperTriangular, b: LowerTriangular):
     return Diagonal(B.multiply(B.diag(a), B.diag(b)))
 
 
-@B.dispatch(UpperTriangular, AbstractMatrix)
-def multiply(a, b):
+@B.dispatch
+def multiply(a: UpperTriangular, b: AbstractMatrix):
     # TODO: Optimise away `B.dense` call.
     return UpperTriangular(a.mat * B.dense(b))
 
 
-@B.dispatch(UpperTriangular, Constant)
-def multiply(a, b):
+@B.dispatch
+def multiply(a: UpperTriangular, b: Constant):
     return UpperTriangular(B.multiply(a.mat, b.const))
 
 
@@ -165,8 +165,8 @@ redirect(B.multiply, (UpperTriangular, Diagonal), (AbstractMatrix, Diagonal))
 # LowRank
 
 
-@B.dispatch(LowRank, LowRank)
-def multiply(a, b):
+@B.dispatch
+def multiply(a: LowRank, b: LowRank):
     assert_compatible(a, b)
 
     if structured(a.left, a.right, b.left, b.right):
@@ -198,28 +198,28 @@ def multiply(a, b):
     return LowRank(left, right, middle)
 
 
-@B.dispatch(Constant, LowRank)
-def multiply(a, b):
+@B.dispatch
+def multiply(a: Constant, b: LowRank):
     assert_compatible(a, b)
     return LowRank(b.left, b.right, B.multiply(a.const, b.middle))
 
 
-@B.dispatch(LowRank, Constant)
-def multiply(a, b):
+@B.dispatch
+def multiply(a: LowRank, b: Constant):
     return multiply(b, a)
 
 
 # Woodbury
 
 
-@B.dispatch(Woodbury, AbstractMatrix)
-def multiply(a, b):
+@B.dispatch
+def multiply(a: Woodbury, b: AbstractMatrix):
     # Expand out Woodbury matrices.
     return B.add(B.multiply(a.diag, b), B.multiply(a.lr, b))
 
 
-@B.dispatch(AbstractMatrix, Woodbury)
-def multiply(a, b):
+@B.dispatch
+def multiply(a: AbstractMatrix, b: Woodbury):
     return multiply(b, a)
 
 
@@ -233,8 +233,8 @@ redirect(B.multiply, (Woodbury, UpperTriangular), (Woodbury, AbstractMatrix))
 # Kronecker
 
 
-@B.dispatch(Kronecker, Kronecker)
-def multiply(a, b):
+@B.dispatch
+def multiply(a: Kronecker, b: Kronecker):
     left_compatible = B.shape(a.left) == B.shape(b.left)
     right_compatible = B.shape(a.right) == B.shape(b.right)
     assert (
@@ -245,12 +245,12 @@ def multiply(a, b):
     return Kronecker(B.multiply(a.left, b.left), B.multiply(a.right, b.right))
 
 
-@B.dispatch(Constant, Kronecker)
-def multiply(a, b):
+@B.dispatch
+def multiply(a: Constant, b: Kronecker):
     assert_compatible(a, b)
     return Kronecker(a.const * b.left, b.right)
 
 
-@B.dispatch(Kronecker, Constant)
-def multiply(a, b):
-    return multiply(b, a)
+@B.dispatch
+def multiply(a: Kronecker, b: Constant):
+    return multiply(b, a)
\ No newline at end of file
