@@ -8,13 +8,6 @@ def _dense(rows):
     return [[B.dense(x) for x in row] for row in rows]
 
 
-def test_block_zero():
-    rows = [[generate("zero:6,6") for _ in range(3)] for _ in range(3)]
-    res = B.block(*rows)
-    approx(res, B.concat2d(*_dense(rows)))
-    assert isinstance(res, Zero)
-
-
 def test_block_dense():
     rows = [[generate("dense:6,6") for _ in range(3)] for _ in range(3)]
     with AssertDenseWarning("could not preserve structure"):
@@ -22,6 +15,18 @@ def test_block_dense():
     approx(res, B.concat2d(*_dense(rows)))
 
 
+def test_block_one_block():
+    rows = [[generate("dense:3,3")]]
+    assert B.block(*rows) is rows[0][0]
+
+
+def test_block_zero():
+    rows = [[generate("zero:6,6") for _ in range(3)] for _ in range(3)]
+    res = B.block(*rows)
+    approx(res, B.concat2d(*_dense(rows)))
+    assert isinstance(res, Zero)
+
+
 def test_block_diag():
     rows = [
         [generate("diag:6"), generate("zero:6,6"), generate("zero:6,3")],
@@ -61,3 +66,10 @@ def test_block_diag_square_check():
     ]
     with AssertDenseWarning("could not preserve structure"):
         assert isinstance(B.block(*rows), Dense)
+
+    rows = [
+        [generate("diag:6"), generate("zero:6,6"), generate("zero:6,6")],
+        [generate("zero:6,6"), generate("zero:6,6"), generate("zero:6,6")],
+    ]
+    with AssertDenseWarning("could not preserve structure"):
+        assert isinstance(B.block(*rows), Dense)
