@@ -2,7 +2,7 @@ import lab as B
 from matrix import Diagonal
 
 # noinspection PyUnresolvedReferences
-from .util import allclose, dense1
+from .util import approx, dense1
 
 
 def test_diagonal_formatting():
@@ -15,8 +15,8 @@ def test_diagonal_formatting():
 
 def test_diagonal_attributes():
     diag = Diagonal(B.ones(3))
-    allclose(diag.diag, B.ones(3))
+    approx(diag.diag, B.ones(3))
 
 
 def test_conversion_to_diagonal(dense1):
-    allclose(Diagonal(dense1), B.diag(B.diag(dense1)))
+    approx(Diagonal(dense1), B.diag(B.diag(dense1)))
